from django.db import models

from django_sourcerer.import_datas.intermediate_layer import Adapter


class AutoModels:
    ModelsFromConfFile = type(Adapter().parse_models_name(), (models.Model,), {
        '__module__': __name__,
    })


class HandleModel:

    def parse_models(self):
        dic = Adapter().parse_models_values()

        for k, v in dic.items():

            if v == 'str':
                AutoModels.ModelsFromConfFile.add_to_class(k, models.CharField(max_length=255, null=True))
            elif v == 'int':
                AutoModels.ModelsFromConfFile.add_to_class(k, models.IntegerField(null=True))
            elif v == 'text':
                AutoModels.ModelsFromConfFile.add_to_class(k, models.TextField(max_length=255, null=True))


HandleModel().parse_models()



#!/usr/bin/env python
from django_sourcerer.import_datas.intermediate_layer import Adapter

from django_sourcerer.models import AutoModels

instance = AutoModels().ModelsFromConfFile
records = Adapter().get_df()

for i in records:
    to_db = [instance(**i)]
    instance.objects.bulk_create(to_db)

# python manage.py shell <django_sourcerer/update_objects.py



import os

from django.conf import settings

from django_sourcerer.import_datas import parsing_config_file
from django_sourcerer.import_datas.import_csv_data import HandleCsvData


class Adapter(object):
    _importers = {
        'csv': HandleCsvData
    }

    def __init__(self):
        yaml_file = os.path.join(settings.BASE_DIR, settings.SOURCERER_CONFIG_FILES[0])
        self.yaml_data = parsing_config_file.ReadConfigFile(yaml_file).import_yaml_file()
        self.source = self.yaml_data['source']
        self.type = self.yaml_data['format']
        self.get_columns = self.yaml_data['columns']
        self.columns = []
        for i in self.get_columns:
            self.columns.append(i['external_name'])
        self.fields = []
        for i in self.get_columns:
            self.fields.append(i['type'])
        self.name = self.yaml_data['name']

    def get_df(self):
        importer = self._importers[self.type]
        call_function = importer(self.source, self.columns)
        call_function.import_()
        get_data = call_function.parse_data()
        return get_data.to_dict('records')

    def parse_models_values(self):
        dict_of_columns_fields = dict(zip(self.columns, self.fields))
        return dict_of_columns_fields

    def parse_models_name(self):
        return self.name



import unittest
from unittest.mock import MagicMock, Mock

from django_sourcerer.import_datas import intermediate_layer, parsing_config_file

test_csv_yaml = {'format': 'csv',
                 'source': 'https://raw.githubusercontent.com/plotly/datasets/master/2014_usa_states.csv',
                 'columns': [{
                     'external_name': 'State'
                 }]}


class TestIntermediateLayer(unittest.TestCase):
    def test_csv_yaml_file_for_intermediate_layer(self):
        parsing_config_file.ReadConfigFile.import_yaml_file = Mock(return_value=test_csv_yaml)
        mocking_importers = intermediate_layer.Adapter._importers["csv"]
        mocking_importers.import_ = MagicMock()
        intermediate_layer.Adapter(test_csv_yaml).get_data_type_columns()

        mocking_importers.import_.assert_called()

    def test_yaml_file_for_xls(self):
        pass

    def test_yaml_file_for_json(self):
        pass

    def test_column_len(self):
        parsing_config_file.ReadConfigFile.import_yaml_file = Mock(return_value=test_csv_yaml)
        get_column = intermediate_layer.Adapter(test_csv_yaml)

        assert get_column.columns == ["State"]


if __name__ == "__main__":
    unittest.main()



import yaml


class ReadConfigFile:

    def __init__(self, file):
        self.parse = file

    def import_yaml_file(self):
        with open(self.parse, 'r') as stream:
            docs = yaml.safe_load(stream)
        return docs



import unittest
import pandas as pd
import requests_mock

from django_sourcerer.import_datas.import_csv_data import HandleCsvData

endpoint = 'https://raw.githubusercontent.com/plotly/datasets/master/2014_usa_states.csv'
column = ['Rank']
test_response_example = 'Test Requests'


class TestImportCsvData(unittest.TestCase):

    def test_parse_data_return_data_frame(self):
        call_function = HandleCsvData(endpoint, column)

        self.assertTrue(isinstance(call_function._parse_data(call_function._get_response()), pd.DataFrame))

    def test_get_response_method_return_not_none(self):
        call_function = HandleCsvData(endpoint, column)
        test_return_value = call_function._get_response()

        self.assertTrue(test_return_value is not None)

    @requests_mock.mock()
    def test_requests_response(self, mock_response):
        mock_response.get(endpoint, text=test_response_example)
        call_function = HandleCsvData(endpoint, column)._get_response().decode()

        self.assertEqual(call_function, test_response_example)


if __name__ == "__main__":
    unittest.main()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()
setuptools.setup(
    name='django_sourcerer',
    version='1.4',
    author="nokia",
    author_email="cmarslan06@gmail.com",
    description="Django app that import and correlating data from external sources.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/nokia-wroclaw/innovativeproject-django-sourcerer",
    packages=setuptools.find_packages(),
    install_requires=[
        'django == 3.0.5',
        'djangorestframework == 3.11.0',
        'requests == 2.23.0',
        'pyyaml == 5.3.1',
        'pandas == 1.0.3',
        'pytest == 5.4.1',
        'requests-mock == 1.7.0',
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)


import requests
import time
import pandas as pd
import io


class HandleCsvData:

    def __init__(self, endpoint, columns):
        self.endpoint = endpoint
        self.columns = columns

    def import_(self):
        return self._get_response()

    def _get_response(self):
        max_attempts = 3
        for trial in range(max_attempts):
            try:
                response = requests.get(self.endpoint, timeout=2)
            except requests.exceptions.ConnectionError:
                time.sleep(2)
            else:
                break
        return response.content

    def parse_data(self):
        df = pd.read_csv(io.StringIO(self.import_().decode('utf-8')), usecols=self.columns)
        return df
